@@ -31,6 +31,7 @@ To get bar lines you have to insert a '|'
 """
 
 import weakref
+import operator
 
 import re
 from duration import Duration
@@ -487,37 +488,34 @@ class Score:
         staff = Staff(self)
         self.m_staffs.append(staff)
         return staff
-    def get_midi_events(self, velocity, start=None, end=None):
+    def get_midi_events(self, start=None, end=None):
         kv = self.m_timeposdict.keys()
         kv.sort()
         if start is None and end is not None:
             return self._generate_midi_events(
-                     [i for i in kv if i < end], velocity,
-                     soundcard.Track)
+                     [i for i in kv if i < end], soundcard.Track)
         elif start is not None and end is None:
             return self._generate_midi_events(
-                     [i for i in kv if i >= start], velocity,
-                     soundcard.Track)
+                     [i for i in kv if i >= start], soundcard.Track)
         elif start is None and end is None:
-            return self._generate_midi_events(kv, velocity, soundcard.Track)
+            return self._generate_midi_events(kv, soundcard.Track)
         else:
             assert start is not None and end is not None
             return self._generate_midi_events(
-               [i for i in kv if start <= i < end], velocity,
-               soundcard.Track)
+               [i for i in kv if start <= i < end], soundcard.Track)
     def get_first_beat_midi_events(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events([kv[0]], velocity, soundcard.Track)
+        return self._generate_midi_events([kv[0]], soundcard.Track)
     def get_last_beat_midi_events(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events([kv[-1]], velocity, soundcard.Track)
-    def get_midi_events_as_percussion(self, velocity):
+        return self._generate_midi_events([kv[-1]], soundcard.Track)
+    def get_midi_events_as_percussion(self):
         kv = self.m_timeposdict.keys()
         kv.sort()
-        return self._generate_midi_events(kv, velocity, soundcard.PercussionTrack)
-    def _generate_midi_events(self, kv, velocity, tracktype):
+        return self._generate_midi_events(kv, soundcard.PercussionTrack)
+    def _generate_midi_events(self, kv, tracktype):
         """
         kv is a list of rat.Rat that tell the timepos for all the tones
         we should generate midi events for.
@@ -526,7 +524,7 @@ class Score:
         track_list = []
         for staff in self.m_staffs:
             for voice in staff.m_voice_list:
-                track_list.append(voice.generate_track_for_voice(staff, kv, velocity, tracktype))
+                track_list.append(voice.generate_track_for_voice(staff, kv, tracktype))
         return track_list
 
 
@@ -656,7 +654,7 @@ class Voice:
                        # need these to generate midi track
                        self.m_coldict[pos1].m_music[p],
                        self.m_coldict[pos2].m_music[p]))
-    def generate_track_for_voice(self, staff, kv, velocity, tracktype):
+    def generate_track_for_voice(self, staff, kv, tracktype):
         # first we find the id()'s of music to tie
         tie_from_v = []
         tie_to_v = []
@@ -673,7 +671,8 @@ class Voice:
             coltimepos = kv[idx]
             musictimepos = musictimepos + (coltimepos - last_timepos)
             if coltimepos in self.m_coldict:
-                for n in self.m_coldict[coltimepos].m_music.values():
+                for n in sorted(self.m_coldict[coltimepos].m_music.values(),
+                        key=operator.attrgetter('m_pitch')):
                     #FIXME this is ugly
                     if id(n) in tie_from_v and (id(n) not in tie_to_v):
                         id_D[n.m_pitch.semitone_pitch()] = i
@@ -697,8 +696,8 @@ class Voice:
                         D[stop_pos].append((i, const.STOP_NOTE, n.m_pitch.semitone_pitch()))
                         i = i + 1
             last_timepos = coltimepos
-        return self.__gen_midi_last_step(D, velocity, tracktype)
-    def __gen_midi_last_step(self, D, velocity, tracktype):
+        return self.__gen_midi_last_step(D, tracktype)
+    def __gen_midi_last_step(self, D, tracktype):
         keys = D.keys()
         keys.sort()
         prev_time = Rat(0)
@@ -712,11 +711,11 @@ class Voice:
                 if e[1] == const.START_NOTE:
                     if delta:
                         ms.notelen_time(delta)
-                    ms.start_note(e[2], velocity)
+                    ms.start_note(e[2], const.DEFAULT_VELOCITY)
                 elif e[1] == const.STOP_NOTE:
                     if delta:
                         ms.notelen_time(delta)
-                    ms.stop_note(e[2], velocity)
+                    ms.stop_note(e[2], const.DEFAULT_VELOCITY)
                 delta = None
         return ms
 
