@@ -376,9 +376,9 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
     def add_gui_for_external_programs(self, page_vbox):
         box, category_vbox = gu.hig_category_vbox(_("Audio File Players"))
         page_vbox.pack_start(box, False)
+        format_info = {}
         if sys.platform != 'win32':
-            format_info = [
-                {'id': 'wav',
+            format_info = {'wav': {
                  # testfile is a file in lesson-files/share
                  'testfile': 'fifth-small-220.00.wav',
                  'label': _("WAV:"),
@@ -394,11 +394,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                         ('esdplay', ''),
                  ],
                 }
-            ]
-        else:
-            format_info = []
-        format_info.extend([
-            {'id': 'midi',
+            }
+        format_info['midi'] = {
              'testfile': 'fanfare.midi',
              'label': _("MIDI:"),
              'players': [
@@ -408,8 +405,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                          ('drvmidi', ''),
                          ('playmidi', ''),
              ],
-            },
-            {'id': 'mp3',
+            }
+        format_info['mp3'] = {
              'testfile': 'fanfare.mp3',
              'label': _("MP3:"),
              'players': [
@@ -418,8 +415,8 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                         ('mpg123', ''),
                         ('alsaplayer', ''),
              ],
-            },
-            {'id': 'ogg',
+            }
+        format_info['ogg'] = {
              'testfile': 'fanfare.ogg',
              'label': _("OGG:"),
              'players': [
@@ -428,17 +425,18 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
                         ('ogg123', ''), 
                         ('alsaplayer', ''),
              ],
-            },
-        ])
+            }
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        for format in format_info:
+        for formatid, format in format_info.items():
             cmd_liststore = gtk.ListStore(gobject.TYPE_STRING)
             for player_data in format['players']:
                 cmd_liststore.append((player_data[0],))
             cmd_combo = gtk.ComboBoxEntry(cmd_liststore)
+            cmd_combo.set_tooltip_text(_("Enter the name of the program. An absolute path is required only if the executable is not found on the PATH."))
             cmd_combo.opts = gtk.combo_box_entry_new_text()
-            cmd_combo.child.set_text(cfg.get_string('sound/%s_player' % format['id']))
-            cmd_combo.opts.child.set_text(cfg.get_string('sound/%s_player_options' % format['id']))
+            cmd_combo.opts.set_tooltip_text(_("The command line options required. Write %s where you want the name of the file to be played. Or omit it to have it added to the end of the string."))
+            cmd_combo.child.set_text(cfg.get_string('sound/%s_player' % formatid))
+            cmd_combo.opts.child.set_text(cfg.get_string('sound/%s_player_options' % formatid))
             for s in format['players']:
                 if s[0] == cmd_combo.child.get_text():
                     for o in s[1:]:
@@ -447,31 +445,27 @@ class ConfigWindow(gtk.Dialog, cfg.ConfigUtils):
             def _changed(widget, formatid):
                 if widget.get_active() != -1:
                     widget.opts.get_model().clear()
+                    format = format_info[formatid]
                     for player_options in format['players'][widget.get_active()][1:]:
                         widget.opts.append_text(player_options)
                     widget.opts.child.set_text(format['players'][widget.get_active()][1])
                 self.set_string('sound/%s_player' % formatid,
                                 widget.child.get_text())
-                binary_found = False
-                if os.path.exists(widget.child.get_text()):
-                    binary_found = True
-                else:
-                    for dir in os.environ['PATH'].split(os.path.pathsep):
-                        if os.path.exists(os.path.join(dir, widget.child.get_text())):
-                            binary_found = True
-                            break
-                widget.testbutton.set_sensitive(binary_found)
-                    
+                widget.testbutton.set_sensitive(bool(
+                    osutils.find_progs((widget.child.get_text(),))))
+
             def _opts_changed(widget, formatid):
                 self.set_string('sound/%s_player_options' % formatid,
                                 widget.child.get_text())
-            cmd_combo.connect('changed', _changed, format['id'])
-            cmd_combo.opts.connect('changed', _opts_changed, format['id'])
+            cmd_combo.connect('changed', _changed, formatid)
+            cmd_combo.opts.connect('changed', _opts_changed, formatid)
             testbutton = gtk.Button(_("Test"))
             testbutton.set_tooltip_text(_("This button is clickable only if the binary is found."))
             cmd_combo.testbutton = testbutton
             testbutton.connect('clicked', self.test_XXX_player,
-                           format['id'], format['testfile'])
+                           formatid, format['testfile'])
+            testbutton.set_sensitive(bool(
+                    osutils.find_progs((cmd_combo.child.get_text(),))))
             box = gu.hig_label_widget(format['label'],
                                       [cmd_combo, cmd_combo.opts, testbutton],
                                       sizegroup, True, True)
