@@ -802,8 +802,8 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             self.g_help_browser = HelpBrowser(self.m_app)
         if self.get_bool('gui/web_browser_as_help_browser'):
             for lang in self.g_help_browser.g_docviewer.m_language, "C":
-                filename = os.path.join(os.getcwdu(), u"help", self.g_help_browser.g_docviewer.m_language, fn)
-                if os.path.isfile(fn):
+                filename = os.path.join(os.getcwdu(), u"help", lang, fn)
+                if os.path.isfile(filename):
                     break
             try:
                 webbrowser.open(filename)
